﻿B4A=true
Group=Default Group
ModulesStructureVersion=1
Type=Class
Version=8
@EndOfDesignText@
#Region "Class Methods"
Sub Class_Globals
	Private MainDB, GameDB As SQL
End Sub

'Initializes the object. You can add parameters to this method if needed.
Public Sub Initialize
	MainDB.Initialize (Main.RootDir, "VirtualBank.db", True)
	MainDB.ExecNonQuery("CREATE TABLE IF NOT EXISTS Players (Name TEXT PRIMARY KEY)")
	MainDB.ExecNonQuery("CREATE TABLE IF NOT EXISTS Games (Name TEXT)")	
End Sub
#End Region

#Region "Game Methods"
Public Sub CreateNewGame (GameName As String, PlayerBalance As Int, SelectedPlayersList As List)
	Dim DirSize As Int = File.ListFiles(Main.GameDir).Size
	If GameName = "" Then GameName = $"Game${DirSize + 1}"$
	MainDB.ExecNonQuery2("INSERT INTO Games VALUES(?)", Array As Object(GameName))
	GameDB.Initialize(Main.GameDir, GameName & ".db", True)
	GameDB.ExecNonQuery("CREATE TABLE Current (Player TEXT, Balance INTEGER, PRIMARY KEY(Player))")
	GameDB.ExecNonQuery("CREATE TABLE History (Player TEXT, Balance INTEGER)")
	GameDB.ExecNonQuery("CREATE TABLE Players (Name TEXT)")
	
	For i = 0 To SelectedPlayersList.Size - 1
		Dim Name As String = SelectedPlayersList.Get(i)
		GameDB.ExecNonQuery2("REPLACE INTO Current VALUES (?,?)", Array As Object(Name, PlayerBalance))
		GameDB.ExecNonQuery2("INSERT INTO History VALUES (?, ?)", Array As Object(Name, PlayerBalance))
		GameDB.ExecNonQuery2("INSERT INTO Players VALUES (?)", Array As Object(Name))
	Next
	BalanceView.GameName = GameName
	StartActivity(BalanceView)
End Sub

Public Sub ReadGame (GameName As String)
	If GameName.EndsWith(".db") = False Then GameName = GameName & ".db"
	If GameDB.IsInitialized Then GameDB.Close
	Try
		GameDB.Initialize(Main.GameDir, GameName, False)
	Catch
		Msgbox($"There was an error reading "${GameName}": ${LastException.Message}."$, "Game Read Error")
	End Try
End Sub

Public Sub ListGames As List
	Dim GL As List
	GL.Initialize
	Dim RS As ResultSet = MainDB.ExecQuery("SELECT * FROM Games")
	Do While RS.NextRow
		GL.Add(RS.GetString2(0))
	Loop
	Return GL
End Sub
#End Region

#Region "Player Methods"
Public Sub AddPlayer (Name As String)
	MainDB.ExecNonQuery2("REPLACE INTO Players VALUES (?)", Array As Object(Name))
End Sub

Public Sub DeletePlayer (Name As String)
	MainDB.ExecNonQuery2("DELETE FROM Players WHERE Name = ?", Array As Object(Name))
End Sub

Public Sub RenamePlayer (OldName As String, NewName As String)
	MainDB.ExecNonQuery2("UPDATE Players SET Name = ? WHERE Name = ?", Array As Object(NewName, OldName))
End Sub

Public Sub ListAllPlayers As List
	Dim PL As List
	PL.Initialize
	Dim RS As ResultSet = MainDB.ExecQuery("SELECT * FROM Players")
	Do While RS.NextRow
		PL.Add(RS.GetString2(0))
	Loop
	Return PL
End Sub

Public Sub ListGamePlayers As List
	Dim PL As List
	PL.Initialize
	Dim RS As ResultSet = GameDB.ExecQuery("SELECT * FROM Players")
	Do While RS.NextRow
		PL.Add(RS.GetString2(0))
	Loop
	Return PL
End Sub
#End Region

#Region "Balance Methods"
Public Sub UpdateBalance (Name As String, Balance As Int)
	Dim OldBal As Int = GameDB.ExecQuerySingleResult2("SELECT Balance FROM Current WHERE Player = ?", Array As String(Name))
	GameDB.ExecNonQuery2("INSERT INTO History Values(?,?)", Array As Object(Name, OldBal))
	GameDB.ExecNonQuery2("REPLACE INTO Current VALUES(?,?)", Array As Object(Name, Balance))
End Sub

Public Sub GetBalance (Name As String, CurrencySymbol As String) As String
	Dim Bal As Int = GameDB.ExecQuerySingleResult2("SELECT Balance FROM Current WHERE Player = ?", Array As String(Name))
	If CurrencySymbol = "" Then CurrencySymbol = "$"
	Dim Resp As String = $"${Name}: ${CurrencySymbol}${NumberFormat(Bal, 0, 2)}"$
	Return Resp
End Sub

Public Sub ListBalanceHistoryForPlayer (Name As String) As List
	Dim BL As List
	BL.Initialize
	Dim RS As ResultSet = GameDB.ExecQuery2("SELECT Balance FROM History WHERE Player = ?", Array As String(Name))
	Do While RS.NextRow
		BL.Add(RS.GetString2(0))
	Loop
	Return BL
End Sub
#End Region

#Region "General Methods"
Public Sub AddGameMeta (Name As String, Value As String)
	GameDB.ExecNonQuery2("REPLACE INTO GameMeta VALUES (?, ?)", Array As Object(Name, Value))
End Sub
#End Region